"""constants.py"""

# pylint: disable=line-too-long
QUERIES = [
    {
        "query": "Is the type of session listed in the report?",
        "keywords": "Service type",
    },
    {
        "query": "Are medications listed or marked 'None recorded' within the encounter note or within the patient chart?",
        "keywords": "medications recorded",
    },
    {
        "query": "Is there a signed consent in the file?",
        "keywords": "consent, legal guardian, member services, foresight terms of use, information and signature",
    },
    {
        "query": "Are allergies or 'no known drug allergies' (NKDA) mentioned in the encounter or within the patient chart?",
        "keywords": "Allergies, NKDA",
    },
    {
        "query": "Is the reason for visit (such as assessment, follow-up) listed in the report?",
        "keywords": "Chief Complaint, Therapy, Follow up",
    },
    {
        "query": "Did treatment start in Q1?",
        "keywords": "Encounter date",
    },
    {
        "query": "If treatment started in Q1, is there a diagnosis within the first note?",
        "keywords": "Encounter date, Diagnosis",
    },
    {
        "query": "Is the presenting problem listed specifically and does it include not only symptoms, but a description of symptoms?",
        "keywords": "presenting problem, chief complaint",
    },
    {
        "query": "In the initial assessment section, are the pre-written examples removed for strengths and risk factors?",
        "context": "If 'Examples: ' is included in the section, output False. If it is not included, output True. Output the strengths and risk factors mentioned",
        "keywords": "strengths or protective factors, risk factors, initial assessment",
    },
    {
        "query": "Are there strengths listed in the initial assessment section?",
        "keywords": "strengths or protective factors, risk factors, initial assessment",
    },
    {
        "query": "Are there risk factors listed in the initial assessment section?",
        "keywords": "strengths or protective factors, risk factors, initial assessment",
    },
    {
        "query": "Is the treatment plan created no later than the 3rd session and congruent with diagnosis? Does it address presenting problems listed during assessment",
        "keywords": "treatment plan",
    },
    {
        "query": "Are goals listed in the treatment plan measurable and specific? Do they demonstrate a way to be measured?",
        "keywords": "goals, treatment plan",
    },
    {
        "query": "Is the patient a minor? If so, did the parents or guardian sign consent for the minor receiving treatment?",
        "context": "Output context showing the legal guardian consent if patient is a minor.",
        "keywords": "patient is a minor, patient is not a minor, legal guardian, consent",
    },
    {
        "query": "Is the diagnosis filled out and consistent with the treatment plan?",
        "keywords": "diagnosis, treatment plan",
    },
    {
        "query": "Is the purpose stated per session?",
        "context": "If purpose is not detailed (more than 1 sentence), output unsatisfactory. If purpose is detailed, output satisfactory. Output an example PSYCHOTHERAPYPurpose from the section you used to generate this.",
        "keywords": "strengths or protective factors, risk factors, initial assessment",
    },
    {
        "query": "Is there a brief narrative of what is currently going on with the member? Does it differ from session to session?",
        "keywords": "behavior, discussion notes",
    },
    {
        "query": "Are the methods used to address the goals of treatment listed? Is client education provided? Gauge how properly these are done.",
        "keywords": "goals of treatment, client education",
    },
    {
        "query": "Does the response section include the member's response to the intervention? If True, gauge how different it is from session to session?",
        "keywords": "discussion notes, response to intervention",
    },
    {
        "query": "Is there a documented plan for what is going to happen next in therapy? Does it include specifics and not just copy/pasted?",
        "keywords": "response, plan, reason",
    },
    {
        "query": "Was there a follow-up on previous barriers/issues and what was the outcome?",
        "keywords": "barriers to treatment, goals, progress / update",
    },
    {
        "query": "Are all sections of PBIRP (Purpose, Behavior, Intervention, Response, and Plan) thoroughly completed and NOT copy/pasted from previous sessions?",
        "keywords": "Purpose, Behavior, Intervention, Response, and Plan",
    },
    {
        "query": "Are modalities listed, such as CBT, EMDR, attachment?",
        "keywords": "Modalities",
    },
    {
        "query": "Is face-to-face time documented? Output each face-to-face time documented.",
        "keywords": "face-to-face",
    },
    {
        "query": "If face-to-face time is not documented, say 'Not Applicable'. If face-to-face time is documented, was it >= 53 minutes?",
        "keywords": "face-to-face",
    },
    {
        "query": "Is the date of the next session documented?",
        "context": "Output all the listed dates of next sessions that were documented",
        "keywords": "Date of next session: ",
    },
    {
        "query": "Are the goals individualized for each member depending on their diagnosis?",
        "keywords": "Goals, discussion notes",
    },
    {
        "query": "Is suicide risk documented according to protocol in the safety section?",
        "keywords": "Suicide risk, safety plan",
    },
    {
        "query": "If the suicide risk is moderate, is the safety plan on file? If member is assessed as acute high risk, was 911 called and appropriate steps taken and documented?",
        "keywords": "Suicide risk, safety plan",
    },
    {
        "query": "Is the Mental Health Status Exam complete (11 out of 14 is considered complete)?",
        "keywords": "Mental health status exam",
    },
    {
        "query": "Is the most recent session the last session?",
        "keywords": "date of discharge, last session, termination session",
    },
    {
        "query": "If it is the last session, is discharge information clearly documented with a follow-up plan?",
        "context": "Output the follow up plan if there is one, if not say false.",
        "keywords": "discharge, follow up plan",
    },
    {
        "query": "If the client is being discharged from services, is there a Patient Case completed to notate this?",
        "context": "If there is a discharge date, output 'No' if 'Patient Case' cannot be found in the provided sections",
        "keywords": "discharge, patient case",
    },
    {
        "query": "If the member has not missed sessions or had planned to call back to reschedule the session, say 'Not Applicable'. If the member has missed sessions or had planned to call back to reschedule the session, is there a patient case present to document a provider's follow up with the member?",
        "keywords": "discharge plan",
    },
    {
        "query": "Are Session Progress Notes individualized each session with updated and specific information and not copy/pasted from previous notes?",
        "keywords": "discussion notes",
    },
    {
        "query": "Give any additional Information or feedback on the patient's chart that you feel is helpful to audit how the patient was treated.",
        "keywords": "medications recorded",
    },
]
