"""medical_document_retriever.py"""

from typing import List

from langchain.schema import BaseRetriever, Document
from langchain.vectorstores import VectorStore


class MedicalDocumentRetriever(BaseRetriever):
    """Retriever for medical documents using vectorstore."""

    vectorstore: VectorStore
    queries: List[dict]
    default_k: int

    def __init__(
        self,
        vectorstore: VectorStore,
        queries: List[dict],
        default_k: int = 4,
    ):
        """Initialize the retriever."""
        self.vectorstore = vectorstore
        self.queries = queries
        self.default_k = default_k

    # pylint: disable=arguments-differ
    def get_relevant_documents(self, query: str, k: int) -> List[Document]:
        """Get texts relevant for a query.

        Args:
            query: string to find relevant texts for

        Returns:
            List of relevant documents
        """

        first_or_default = next(
            (p for p in self.queries if p.get("query") == query), None
        )
        search_query = (
            first_or_default.get("keywords") if first_or_default is not None else query
        )

        # k = (
        #     first_or_default.get("k")
        #     if first_or_default is not None
        #     else self.default_k
        # )

        return self.vectorstore.similarity_search(
            query=search_query,
            k=k,
        )

    async def aget_relevant_documents(self, query: str, k: int) -> List[Document]:
        """Get documents relevant for a query.

        Args:
            query: string to find relevant documents for

        Returns:
            List of relevant documents
        """

        return self.vectorstore.similarity_search(
            query=query,
            k=k,
        )
