"""main.py"""
import json
from typing import Dict, Optional

from langchain import SagemakerEndpoint
from langchain.llms.sagemaker_endpoint import LLMContentHandler


class ContentHandler(LLMContentHandler):
    """ContentHandler for MPT LLM on SageMaker"""

    content_type = "application/json"
    accepts = "application/json"
    cur_prompt = ""

    def set_cur_prompt(self, prompt):
        """set curPrompt"""
        self.cur_prompt = prompt

    def get_cur_prompt(self):
        """get curPrompt"""
        return self.cur_prompt

    def transform_input(self, prompt: str, model_kwargs: Dict) -> bytes:
        input_str = json.dumps({"text_inputs": prompt, **model_kwargs})
        self.set_cur_prompt(prompt)
        return input_str.encode("utf-8")

    def transform_output(self, output: bytes) -> str:
        response_json = json.loads(output.read().decode("utf-8"))
        try:
            ret = response_json[0][0]["generated_text"].split("### Response:")[1]
        except Exception as _:
            ret = response_json[0][0]["generated_text"]
        return ret


def create_sagemaker_llm(
    endpoint_name: str,
    credentials_profile_name="default",
    region_name="us-east-2",
    model_kwargs: Optional[Dict] = {
        "temperature": 1e-10,
        "max_new_tokens": 30,
    },
):
    """Create a SageMaker LLM"""
    content_handler = ContentHandler()

    llm = SagemakerEndpoint(
        endpoint_name=endpoint_name,
        credentials_profile_name=credentials_profile_name,
        region_name=region_name,
        model_kwargs=model_kwargs,
        content_handler=content_handler,
    )

    return llm
