"""print.py"""

from typing import Any, Dict


def print_inference_result(
    question_number: int,
    qa_response_obj: Dict[str, Any],
    print_intermediate_steps: bool = False,
):
    """Print the result of a question-answering inference."""
    runtime = qa_response_obj.get("runtime")
    intermediate_steps = qa_response_obj.get("intermediate_steps", None)

    print(f" QUESTION {question_number} ({(runtime):.2f} seconds) ".center(120, "─"))
    print("")
    print(f"QUESTION: {qa_response_obj.get('query')}")
    print(f"RESPONSE: {qa_response_obj.get('result')}")
    print("")
    if print_intermediate_steps:
        if intermediate_steps is not None:
            print("INTERMEDIATE STEPS:")

            for i, step in enumerate(intermediate_steps):
                print(f"  ┌─ Step {i+1} ".ljust(120, "─"))
                for line in step.split("\n"):
                    print(f"  │  {line}")
                print("  └─".ljust(120, "─"))

        print("")
