"""map_reduce.py"""
# pylint: disable=import-error, too-many-arguments

from langchain.base_language import BaseLanguageModel
from langchain.chains.question_answering import load_qa_chain
from langchain.schema import BaseRetriever


from lib import (
    MAP_REDUCE_MAP_PROMPT,
    MAP_REDUCE_REDUCE_PROMPT,
    MedicalDocumentRetrievalQA,
)


def create_map_reduce_medical_document_retrieval_qa_chain(
    retriever: BaseRetriever,
    map_llm: BaseLanguageModel,
    reduce_llm: BaseLanguageModel,
    map_prompt=MAP_REDUCE_MAP_PROMPT,
    reduce_prompt=MAP_REDUCE_REDUCE_PROMPT,
    return_map_steps=False,
):
    """Create a map-reduce question-answering chain."""

    final_qa_chain = load_qa_chain(
        llm=map_llm,
        reduce_llm=reduce_llm,
        chain_type="map_reduce",
        question_prompt=map_prompt,
        combine_prompt=reduce_prompt,
        return_map_steps=return_map_steps,
    )

    return MedicalDocumentRetrievalQA(
        retriever=retriever,
        combine_documents_chain=final_qa_chain,
    )
