"""map_refine.py"""
# pylint: disable=import-error, too-many-arguments

from langchain.base_language import BaseLanguageModel
from langchain.chains.question_answering import load_qa_chain
from langchain.schema import BaseRetriever


from lib import (
    MAP_REFINE_MAP_PROMPT,
    MAP_REFINE_REFINE_PROMPT,
    MedicalDocumentRetrievalQA,
)


def create_map_refine_medical_document_retrieval_qa_chain(
    retriever: BaseRetriever,
    map_llm: BaseLanguageModel,
    refine_llm: BaseLanguageModel,
    map_prompt=MAP_REFINE_MAP_PROMPT,
    refine_prompt=MAP_REFINE_REFINE_PROMPT,
    return_refine_steps=False,
):
    """Create a map-refine question-answering chain."""

    final_qa_chain = load_qa_chain(
        llm=map_llm,
        refine_llm=refine_llm,
        chain_type="refine",
        question_prompt=map_prompt,
        refine_prompt=refine_prompt,
        return_refine_steps=return_refine_steps,
    )

    return MedicalDocumentRetrievalQA(
        retriever=retriever,
        combine_documents_chain=final_qa_chain,
    )
